@@ -16,7 +16,7 @@ namespace PicdemBootloader
 //----------------------------------------------------------------------------
 class ConfigWidget: public ::Programmer::ConfigWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ConfigWidget(const ::Programmer::Group &group, TQWidget *parent);
